### Name: npscoef
### Title: Smooth Coefficient Kernel Regression
### Aliases: npscoef npscoef.call npscoef.default npscoef.formula
###   npscoef.scbandwidth
### Keywords: nonparametric

### ** Examples

# EXAMPLE 1 (INTERFACE=FORMULA): Typically, the variables z will be
# equal to the regressors x, as in the following example.

set.seed(12345)

n <- 250
x <- sort(runif(n,min=-2*pi,max=2*pi))
y <- sin(x) + rnorm(n,sd = 0.2)

bw <- npscoefbw(formula=y~x)

model <- npscoef(bw)

# We could manually plot fitted values and error bounds as follows:

plot(x,y)
lines(x,predict(model))
lines(x,predict(model)-2*se(model),lty=2,col="red")
lines(x,predict(model)+2*se(model),lty=2,col="red")

# EXAMPLE 1 (INTERFACE=DATAFRAME): Typically, the variables z will be
# equal to the regressors x, as in the following example.

set.seed(12345)

n <- 250
x <- sort(runif(n,min=-2*pi,max=2*pi))
y <- sin(x) + rnorm(n,sd = 0.2)

bw <- npscoefbw(xdat=x, ydat=y)

model <- npscoef(bw)

# We could manually plot fitted values and error bounds as follows:

plot(x,y)
lines(x,predict(model))
lines(x,predict(model)-2*se(model),lty=2,col="red")
lines(x,predict(model)+2*se(model),lty=2,col="red")

# EXAMPLE 2 (INTERFACE=FORMULA): We can handle z and x being different
# (this would be useful in, say, a time series context where z might be
# time yielding a time-varying smooth coefficient model)

n <- 250
x <- runif(n)
z <- runif(n, min=-2, max=2)
y <- x*exp(z)*(1.0+rnorm(n,sd = 0.2))
bw <- npscoefbw(y~x|z)
model <- npscoef(bw)
plot(model) 

# EXAMPLE 2 (INTERFACE=DATAFRAME): We can handle z and x being different
# (this would be useful in, say, a time series context where z might be
# time yielding a time-varying smooth coefficient model)

n <- 250
x <- runif(n)
z <- runif(n, min=-2, max=2)
y <- x*exp(z)*(1.0+rnorm(n,sd = 0.2))
bw <- npscoefbw(xdat=x, ydat=y, zdat=z)
model <- npscoef(bw)
plot(model) 



